---
hide:
  - navigation
  - toc
---

# metasp

A framework for creating systems using meta-programming in ASP. The goal is to simplify the process of defining and running meta-systems by providing a structured way to specify syntax, semantics, and solver configurations.

- No need for any `python` coding.
- Flexible: use different solvers such as `clingo`, `clingodl`, and more.
- Option to define custom output formatting functions.
- Focus on specifying syntax and semantics directly in ASP.
  - *Modelers should primarily concentrate on this aspect.*
- Supports combining multiple approaches or systems.



!!! info
    *metasp* is part of the [Potassco](https://potassco.org) suite.
